Database design
===============

To design the database, we first analyze which entities need to be represented.
From there, we then derive tables for the database accordingly.

.. toctree::
   :maxdepth: 2

   entities/index
   tables/index

